/*
 * terry.c -- Declarations and friends.
 *
 * This file is part of Terry, a Python binding for RenderMan.
 * 
 * Copyright (C) 1996, 1997 Ture Plsson.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * The RenderMan (R) Interface Procedures and RIB Protocol are:
 *     Copyright 1988, 1989, Pixar.  All rights reserved.
 * RenderMan (R) is a registered trademark of Pixar.
 */

#ifndef TERRY_H
#define TERRY_H

#define TERRY_VERSION "0.3"

enum simpletype
{
    /*
     * NOTE: If you change this, you must also change terry.c, igen.py
     * and terry.py. This should probably be automagically generated
     * somehow...
     */
    T_BOOLEAN	= 0,
    T_INTEGER 	= 1,
    T_FLOAT 	= 2,
    T_STRING 	= 3,
    T_TOKEN 	= 4,
    T_POINT 	= 5,
    T_COLOR	= 6,
    T_MATRIX	= 7,
    T_BASIS	= 8,
    T_BOUND	= 9,
    T_LIGHTHANDLE = 10,
    T_OBJECTHANDLE = 11,
    T_FLOATFUNC = 12,
    T_FUNC	= 13,
    T_POINTER	= 14
};

struct type
{
    int varying;
    enum simpletype base;
    int dimension;
};

#define xmalloc(x) malloc(x)
#define xfree(x) free(x)

extern PyObject *terry_error;
extern int terry_color_samples;

int terry_alloc_parameter_list(int, RtToken**, RtPointer**);
int terry_parse_parameter_list(PyObject*, RtToken*, RtPointer*);
int terry_parse_args(int, PyObject*, PyObject**, struct type *, ...);
void terry_free_parameter_list(int, RtToken*, RtPointer*);
int terry_convert_list_of_values(PyObject*, struct type *, void*, int);
int terry_sizeof(struct type *type);
PyObject* terry_py_setsymdict(PyObject*, PyObject*);

#endif
