# terry.py -- High-level part of the Terry Python-to-Renderman binding.
#
# This file is part of Terry, a Python binding for RenderMan.
# 
# Copyright (C) 1996, 1997 Ture Plsson.
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
# 
# The RenderMan (R) Interface Procedures and RIB Protocol are:
#     Copyright 1988, 1989, Pixar.  All rights reserved.
# RenderMan (R) is a registered trademark of Pixar.

import regex
import string
from _terry import *

symdict = {}
setsymdict(symdict)

def declare_py(name, decl):
    symdict[name] = parsedecl(decl)
    return name

def declare(name, decl):
    declare_py(name, decl)
    declare_c(name, decl)
    return name

def parsedecl(decl):
    typeregex = regex.compile('\(uniform\|varying\|\) *\([a-z]+\)\(\[[0-9]+\]\|\)')
    # NOTE: This had better be in the same order as the enum in terry.h
    basetypes = ['boolean', 'integer', 'float', 'string', 'token',
		 'point', 'color', 'matrix', 'basis', 'bound', 'lighthandle',
		 'objecthandle', 'floatfunc', 'func', 'pointer' ]

    typeregex.match(decl)

    if typeregex.group(1) == 'varying':
	varying = 1
    else:
	varying = 0

    base = basetypes.index(typeregex.group(2));

    if len(typeregex.group(3)) > 2:
	dimension = string.atoi(typeregex.group(3)[1:-1])
    else:
	dimension = 0

    return (varying, base, dimension)
    
declare_py("intensity", "uniform float")
declare_py("lightcolor", "uniform color")
declare_py("from", "uniform point")
declare_py("to", "uniform point")
declare_py("coneangle", "uniform float")
declare_py("conedeltaangle", "uniform float")
declare_py("beamdistribution", "uniform float")
declare_py("fov", "uniform float")

declare_py("Ka", "uniform float")
declare_py("Kd", "uniform float")
declare_py("Ks", "uniform float")
declare_py("roughness", "uniform float")
declare_py("texturename", "uniform string")
declare_py("specularcolor", "uniform color")

declare_py("mindistance", "uniform float")
declare_py("maxdistance", "uniform float")
declare_py("background", "uniform color")

declare_py("Cs", "varying color")
declare_py("Cs", "varying color")
declare_py("N", "varying point")
declare_py("Np", "uniform point")
declare_py("s", "varying float")
declare_py("t", "varying float")
declare_py("st", "varying float[2]")

declare_py("P", "varying point")
declare_py("Pw", "varying float[4]")
declare_py("Pz", "varying float")
